@@ -25,3 +25,19 @@ class NMActiveConnectionState(object):
     ACTIVATED = 2      # there is a connection to the network
     DEACTIVATING = 3   # network connection is being torn down and cleaned up
     DEACTIVATED = 4    # network connection is disconnected and will be removed
+
+
+class NMDeviceState(object):
+    UNKNOWN = 0
+    UNMANAGED = 10
+    UNAVAILABLE = 20
+    DISCONNECTED = 30
+    PREPARE = 40
+    CONFIG = 50
+    NEED_AUTH = 60
+    IP_CONFIG = 70
+    IP_CHECK = 80
+    SECONDARIES = 90
+    ACTIVATED = 100
+    DEACTIVATING = 110
+    FAILED = 120
